/*******************************************************************************

  
  Copyright(c) 1999 - 2008 Intel Corporation. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify it 
  under the terms of the GNU General Public License as published by the Free 
  Software Foundation; either version 2 of the License, or (at your option) 
  any later version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
  more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 59 
  Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
  The full GNU General Public License is included in this distribution in the
  file called LICENSE.
  
  Contact Information:
  e1000 mailing list <e1000-devel@lists.sourceforge.net>
  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497

*******************************************************************************/

#include <stdio.h>
#include "ethregs.h"


extern int clr;
extern int offset;

void dump_ichlan_registers(volatile void *mem, u32 size,
                           enum e1000_mac_type mac_type)
{
	unsigned int i, j, n;
	char name[16];

	for (i = 0; i < size; i += sizeof(u32)) {
		switch (i & 0xffffffff) {
		case E1000_CTRL:
			sprintf(name, "CTRL"); break;
		case E1000_STATUS:
			sprintf(name, "STATUS"); break;
		case 0x000C:
			if ((mac_type == e1000_ich8lan) ||
			    (mac_type == e1000_ich10lan))
				continue;
			sprintf(name, "STRAP"); break;
		case E1000_EECD:
			if (mac_type > e1000_ich9lan) continue;
			sprintf(name, "EECD"); break;
		case E1000_CTRL_EXT:
			sprintf(name, "CTRL_EXT"); break;
		case E1000_MDIC:
			sprintf(name, "MDIC"); break;
		case E1000_FEXTNVM:
			sprintf(name, "FEXTNVM"); break;
		case E1000_FCAH:
			sprintf(name, "FEXT"); break;
#define E1000_FEXTNVM2 0x00030  /* Future Extended2 NVM */
		case E1000_FEXTNVM2:
			if (mac_type < e1000_pchlan) continue;
			sprintf(name, "FEXTNVM2"); break;
		case E1000_KMRNCTRLSTA:
			sprintf(name, "KMRNCTRLSTA"); break;
#define E1000_BUSNUM   0x00038  /* Device and Bus Number */
		case E1000_BUSNUM:
			if (mac_type < e1000_ich9lan) continue;
			sprintf(name, "BUSNUM"); break;
#define E1000_FEXTNVM3 0x0003C  /* Future Extended3 NVM */
		case E1000_FEXTNVM3:
			if (mac_type < e1000_pchlan) continue;
			sprintf(name, "FEXTNVM3"); break;
#define E1000_LCDPCISTA 0x000A0 /* LAN Connected Device PCI Status */
		case E1000_LCDPCISTA:
			if (mac_type != e1000_ich10lan) continue;
			sprintf(name, "LCDPCISTA"); break;
#define E1000_LCPCISTA  0x000A8 /* LAN Controller PCI Status */
		case E1000_LCPCISTA:
			if (mac_type != e1000_ich10lan) continue;
			sprintf(name, "LCPCISTA"); break;
#define E1000_LCLCDFC   0x000B0 /* LAN Controller / LCD Flow Control */
		case E1000_LCLCDFC:
			if (mac_type != e1000_ich10lan) continue;
			sprintf(name, "LCLCDFC"); break;
		case E1000_ICR:
			if (!clr) continue;
			sprintf(name, "ICR"); break;
		case E1000_ITR:
			sprintf(name, "ITR"); break;
		case E1000_ICS: // Write-only
			sprintf(name, "ICS"); break;
		case E1000_IMS:
			sprintf(name, "IMS"); break;
		case E1000_IMC: // Write-only
			sprintf(name, "IMC"); break;
		case E1000_IAM:
			sprintf(name, "IAM"); break;
		case E1000_RCTL:
			sprintf(name, "RCTL"); break;
#define E1000_RCTL1    0x00104  /* Rx Control 1 - RW */
		case E1000_RCTL1:
			if (mac_type < e1000_pchlan) continue;
			sprintf(name, "RCTL1"); break;
		case E1000_FCTTV:
			sprintf(name, "FCTTV"); break;
		case E1000_FCRTV:
			if (mac_type < e1000_ich10lan) continue;
			sprintf(name, "FCRTV"); break;
		case E1000_TCTL:
			sprintf(name, "TCTL"); break;
		case E1000_TIPG:
			sprintf(name, "TIPG"); break;
		case E1000_AIT:
			sprintf(name, "AIT"); break;
		case E1000_LEDCTL:
			sprintf(name, "LEDCTL"); break;
		case E1000_EXTCNF_CTRL:
			sprintf(name, "EXTCNF_CTRL"); break;
		case E1000_EXTCNF_SIZE:
			sprintf(name, "EXTCNF_SIZE"); break;
		case E1000_PHY_CTRL:
			sprintf(name, "PHY_CTRL"); break;
		case E1000_PBA:
			sprintf(name, "PBA"); break;
		case E1000_PBS:
			sprintf(name, "PBS"); break;
		case E1000_ERT:
			sprintf(name, "ERT"); break;
		case E1000_FCRTL:
			sprintf(name, "FCRTL"); break;
		case E1000_FCRTH:
			sprintf(name, "FCRTH"); break;
		case E1000_PSRCTL:
			sprintf(name, "PSRCTL"); break;
		case E1000_RDBAL(0):
			sprintf(name, "RDBAL"); break;
		case E1000_RDBAH(0):
			sprintf(name, "RDBAH"); break;
		case E1000_RDLEN(0):
			sprintf(name, "RDLEN"); break;
		case E1000_RDH(0):
			sprintf(name, "RDH"); break;
		case E1000_RDT(0):
			sprintf(name, "RDT"); break;
		case E1000_RDTR:
			sprintf(name, "RDTR"); break;
		case E1000_RXDCTL(0):
			sprintf(name, "RXDCTL"); break;
		case E1000_RDBAL(1):
			sprintf(name, "RDBAL1"); break;
		case E1000_RDBAH(1):
			sprintf(name, "RDBAH1"); break;
		case E1000_RDLEN(1):
			sprintf(name, "RDLEN1"); break;
		case E1000_RDH(1):
			sprintf(name, "RDH1"); break;
		case E1000_RDT(1):
			sprintf(name, "RDT1"); break;
		case E1000_RXDCTL(1):
			if (mac_type != e1000_ich10lan) continue;
			sprintf(name, "RXDCTL1"); break;
		case E1000_RADV:
			sprintf(name, "RADV"); break;
		case E1000_RSRPD:
			sprintf(name, "RSRPD"); break;
		case E1000_RAID:
			sprintf(name, "RAID"); break;
		case E1000_CPUVEC:
			sprintf(name, "CPUVEC"); break;
		case E1000_TDFH:
			sprintf(name, "TDFH"); break;
		case E1000_TDFT:
			sprintf(name, "TDFT"); break;
		case E1000_TDFHS:
			sprintf(name, "TDFHS"); break;
		case E1000_TDFTS:
			sprintf(name, "TDFTS"); break;
		case E1000_TDFPC:
			sprintf(name, "TDFPC"); break;
		case E1000_TDBAL(0):
			sprintf(name, "TDBAL"); break;
		case E1000_TDBAH(0):
			sprintf(name, "TDBAH"); break;
		case E1000_TDLEN(0):
			sprintf(name, "TDLEN"); break;
		case E1000_TDH(0):
			sprintf(name, "TDH"); break;
		case E1000_TDT(0):
			sprintf(name, "TDT"); break;
		case E1000_TIDV:
			sprintf(name, "TIDV"); break;
		case E1000_TXDCTL(0):
			sprintf(name, "TXDCTL"); break;
		case E1000_TADV:
			sprintf(name, "TADV"); break;
		case E1000_TARC(0):
			sprintf(name, "TARC0"); break;
		case E1000_TDBAL(1):
			sprintf(name, "TDBAL1"); break;
		case E1000_TDBAH(1):
			sprintf(name, "TDBAH1"); break;
		case E1000_TDLEN(1):
			sprintf(name, "TDLEN1"); break;
		case E1000_TDH(1):
			sprintf(name, "TDH1"); break;
		case E1000_TDT(1):
			sprintf(name, "TDT1"); break;
		case E1000_TXDCTL(1):
			sprintf(name, "TXDCTL1"); break;
		case E1000_TARC(1):
			sprintf(name, "TARC1"); break;
		case E1000_CRCERRS:
			if (!clr) continue;
			sprintf(name, "CRCERRS"); break;
		case E1000_ALGNERRC:
			if (!clr) continue;
			sprintf(name, "ALGNERRC"); break;
		case E1000_RXERRC:
			if (!clr) continue;
			sprintf(name, "RXERRC"); break;
		case E1000_MPC:
			if (!clr) continue;
			sprintf(name, "MPC"); break;
		case E1000_SCC:
			if ((!clr) || (mac_type >= e1000_pchlan)) continue;
			sprintf(name, "SCC"); break;
		case E1000_ECOL:
			if ((!clr) || (mac_type >= e1000_pchlan)) continue;
			sprintf(name, "ECOL"); break;
		case E1000_MCC:
			if ((!clr) || (mac_type >= e1000_pchlan)) continue;
			sprintf(name, "MCC"); break;
		case E1000_LATECOL:
			if ((!clr) || (mac_type >= e1000_pchlan)) continue;
			sprintf(name, "LATECOL"); break;
		case E1000_COLC:
			if ((!clr) || (mac_type >= e1000_pchlan)) continue;
			sprintf(name, "COLC"); break;
		case E1000_DC:
			if ((!clr) || (mac_type >= e1000_pchlan)) continue;
			sprintf(name, "DC"); break;
		case E1000_TNCRS:
			if ((!clr) || (mac_type >= e1000_pchlan)) continue;
			sprintf(name, "TNCRS"); break;
		case E1000_CEXTERR:
			if (!clr) continue;
			sprintf(name, "CEXTERR"); break;
		case E1000_RLEC:
			if (!clr) continue;
			sprintf(name, "RLEC"); break;
		case E1000_XONRXC:
			if (!clr) continue;
			sprintf(name, "XONRXC"); break;
		case E1000_XONTXC:
			if (!clr) continue;
			sprintf(name, "XONTXC"); break;
		case E1000_XOFFRXC:
			if (!clr) continue;
			sprintf(name, "XOFFRXC"); break;
		case E1000_XOFFTXC:
			if (!clr) continue;
			sprintf(name, "XOFFTXC"); break;
		case E1000_FCRUC:
			if (!clr) continue;
			sprintf(name, "FCRUC"); break;
		case E1000_GPRC:
			if (!clr) continue;
			sprintf(name, "GPRC"); break;
		case E1000_BPRC:
			if (!clr) continue;
			sprintf(name, "BPRC"); break;
		case E1000_MPRC:
			if (!clr) continue;
			sprintf(name, "MPRC"); break;
		case E1000_GPTC:
			if (!clr) continue;
			sprintf(name, "GPTC"); break;
		case E1000_GORCL:
			if (!clr) continue;
			sprintf(name, "GORCL"); break;
		case E1000_GORCH:
			if (!clr) continue;
			sprintf(name, "GORCH"); break;
		case E1000_GOTCL:
			if (!clr) continue;
			sprintf(name, "GOTCL"); break;
		case E1000_GOTCH:
			if (!clr) continue;
			sprintf(name, "GOTCH"); break;
		case E1000_RNBC:
			if (!clr) continue;
			sprintf(name, "RNBC"); break;
		case E1000_RUC:
			if (!clr) continue;
			sprintf(name, "RUC"); break;
		case E1000_RFC:
			if (!clr) continue;
			sprintf(name, "RFC"); break;
		case E1000_ROC:
			if (!clr) continue;
			sprintf(name, "ROC"); break;
		case E1000_RJC:
			if (!clr) continue;
			sprintf(name, "RJC"); break;
		case E1000_MGTPRC:
			if (!clr) continue;
			sprintf(name, "MGTPRC"); break;
		case E1000_MGTPDC:
			if (!clr) continue;
			sprintf(name, "MGTPDC"); break;
		case E1000_MGTPTC:
			if (!clr) continue;
			sprintf(name, "MGTPTC"); break;
#define E1000_TCBPD    0x040D8  /* Tx Circuit Breaker Packets Dropped */
		case E1000_TCBPD:
			if ((!clr) || (mac_type < e1000_pchlan)) continue;
			sprintf(name, "TCBPD"); break;
		case E1000_TORL:
			if (!clr) continue;
			sprintf(name, "TORL"); break;
		case E1000_TORH:
			if (!clr) continue;
			sprintf(name, "TORH"); break;
		case E1000_TOTL:
			if (!clr) continue;
			sprintf(name, "TOTL"); break;
		case E1000_TOTH:
			if (!clr) continue;
			sprintf(name, "TOTH"); break;
		case E1000_TPR:
			if (!clr) continue;
			sprintf(name, "TPR"); break;
		case E1000_TPT:
			if (!clr) continue;
			sprintf(name, "TPT"); break;
		case E1000_MPTC:
			if (!clr) continue;
			sprintf(name, "MPTC"); break;
		case E1000_BPTC:
			if (!clr) continue;
			sprintf(name, "BPTC"); break;
		case E1000_TSCTC:
			if (!clr) continue;
			sprintf(name, "TSCTC"); break;
		case E1000_TSCTFC:
			if ((!clr) || (mac_type > e1000_ich10lan)) continue;
			sprintf(name, "TSCTFC"); break;
		case E1000_IAC:
			if (!clr) continue;
			sprintf(name, "IAC"); break;
		case E1000_RXCSUM:
			sprintf(name, "RXCSUM"); break;
		case E1000_RFCTL:
			sprintf(name, "RFCTL"); break;
		case E1000_MTA:
			for (j=i, n=0; n<32; n++) {
				sprintf(name, "MTA[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case E1000_RA:
			for (j=i, n=0; n<7; n++) {
				sprintf(name, "RAL[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
				sprintf(name, "RAH[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
#define E1000_SHRA     0x05438  /* Shared Receive Address [3:0] */
		case E1000_SHRA:
			if (mac_type == e1000_ich8lan) continue;
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "SHRAL[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
				sprintf(name, "SHRAH[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case E1000_WUC:
			sprintf(name, "WUC"); break;
		case E1000_WUFC:
			sprintf(name, "WUFC"); break;
		case E1000_WUS:
			sprintf(name, "WUS"); break;
		case E1000_MRQC:
			if (mac_type > e1000_ich10lan) continue;
			sprintf(name, "MRQC"); break;
		case E1000_MANC:
			sprintf(name, "MANC"); break;
#define E1000_MANC2    0x05824  /* Management Control 2 */
		case E1000_MANC2:
			if (mac_type < e1000_pchlan) continue;
			sprintf(name, "MANC2"); break;
		case E1000_IPAV:
			sprintf(name, "IPAV"); break;
		case E1000_IP4AT:
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "IP4AT[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case E1000_MANC2H:
			sprintf(name, "MANC2H"); break;
#define E1000_MANC2H2     0x05870 /* Management Control To Host 2 - RW */
		case E1000_MANC2H2:
			if (mac_type < e1000_pchlan) continue;
			sprintf(name, "MANC2H2"); break;
		case E1000_RSSIM:
			sprintf(name, "RSSIM"); break;
		case E1000_RSSIR:
			sprintf(name, "RSSIR"); break;
		case E1000_IP6AT:
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "IP6AT[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
#define E1000_DCR         0x05B00 /* DMA Control */
		case E1000_DCR:
			sprintf(name, "DCR"); break;
		case E1000_SWSM:
			sprintf(name, "H2ME"); break;
		case E1000_FWSM:
			sprintf(name, "FWSM"); break;
		case E1000_RETA(0):
			for (j=i, n=0; n<32; n++) {
				sprintf(name, "RETA[%d]", n);
				printit8(j, name, mem);
				j += sizeof(u8);
			}
			continue;
		case E1000_RSSRK(0):
			for (j=i, n=0; n<40; n++) {
				sprintf(name, "RSSRK[%d]", n);
				printit8(j, name, mem);
				j += sizeof(u8);
			}
			continue;
		case E1000_FFLT:
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "FFLT[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case E1000_FFMT:
			for (j=i, n=0; n<128; n++) {
				sprintf(name, "FFMT[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case E1000_FFVT:
			for (j=i, n=0; n<128; n++) {
				sprintf(name, "FFVT[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		default:
			continue;
		}
		printit32(i, name, mem);
	}
}

// vi:ts=4:sw=4:ht=4:
